@@ -22,9 +22,11 @@
 
 class ThemeMetadata;
 
-class ThemesModel: public QAbstractListModel
+class ThemesModel : public QAbstractListModel
 {
     Q_OBJECT
+    Q_PROPERTY(QString currentTheme READ currentTheme WRITE setCurrentTheme NOTIFY currentIndexChanged)
+    Q_PROPERTY(int currentIndex READ currentIndex NOTIFY currentIndexChanged)
 public:
     enum Roles {
         IdRole = Qt::UserRole,
@@ -38,23 +40,35 @@ public:
         LicenseRole,
         CopyrightRole,
         ThemeApiRole,
-        ConfigFileRole
+        ConfigFileRole,
+        CurrentBackgroundRole,
     };
+    Q_ENUM(Roles)
 
-    explicit ThemesModel(QObject *parent=nullptr);
+    explicit ThemesModel(QObject *parent = nullptr);
     ~ThemesModel() Q_DECL_OVERRIDE;
 
     int rowCount(const QModelIndex &parent) const Q_DECL_OVERRIDE;
     QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
+    QHash<int, QByteArray> roleNames() const override;
+
+    QString currentTheme() const;
+    void setCurrentTheme(const QString &theme);
+    int currentIndex() const;
 
 public Q_SLOTS:
     void populate();
+Q_SIGNALS:
+    void currentIndexChanged();
 
 private:
     void add(const QString &name, const QString &path);
     void dump(const QString &id, const QString &path);
 
+    int m_currentIndex;
     QList<ThemeMetadata> mThemeList;
+    QHash<QString, QString> m_currentWallpapers;
 };
 
-#endif //THEMESMODEL_H
+#endif // THEMESMODEL_H
